@@ -3,6 +3,7 @@ from django.forms.models import inlineformset_factory
 from polls.models import Choice, Poll
 from polls.forms import PollForm, PollVoteForm
 
+
 def get_poll_form(instance, request):
     data = request.POST
     if not data:
@@ -11,15 +12,19 @@ def get_poll_form(instance, request):
         formset = ChoiceFormSet(instance=instance)
     else:
         ChoiceFormSet = inlineformset_factory(Poll, Choice)
-            
-        form = PollForm(data, instance=instance) if instance else PollForm(data)
+
+        form = PollForm(
+            data,
+            instance=instance) if instance else PollForm(
+            data)
         form.instance.user = request.user
         formset = ChoiceFormSet(data, instance=form.instance)
-    
+
     return (form, formset)
-    
+
+
 def get_poll_vote_form(instance):
     form = PollVoteForm()
     form.construct(instance)
-    
-    return form
\ No newline at end of file
+
+    return form
