@@ -7,17 +7,15 @@ $(document).ready(function() {
         var form = $(this);
         
         $.post(form.attr('action'), form.serialize(), function(data) {
+            var alert = $(data).find('.alerts');
             var source = $(data).find(form.attr('data-source'));
             
+            $('.alerts').html(alert);
+            $('.alerts').replaceWith(alert);
+            
             if(source.length > 0) {
                 $('.poll').replaceWith(source);
                 window.location.hash = '#voted'
-            } else {
-                if($(':checked').length == 0 && $(':selected').length == 0) {
-                    $('.alerts').html(message1);
-                } else {
-                    $('.alerts').html(message2);
-                }
             }
         });
         
